/** https://core.telegram.org/bots/api#html-style */
export const parse_mode = "HTML";
/** Escape the input text to be displayed as it is */
export function escape(text) {
    return text
        .replace(/&/g, "&amp;")
        .replace(/</g, "&lt;")
        .replace(/>/g, "&gt;");
}
/** Format the input text bold */
export function bold(text) {
    return `<b>${text}</b>`;
}
/** Format the input text italic */
export function italic(text) {
    return `<i>${text}</i>`;
}
/** Strikethrough the input text */
export function strikethrough(text) {
    return `<s>${text}</s>`;
}
/** Underline the input text */
export function underline(text) {
    return `<u>${text}</u>`;
}
/** Format the input text as spoiler */
export function spoiler(text) {
    return `<span class="tg-spoiler">${text}</span>`;
}
/** Format the input text as monospace */
export function monospace(text) {
    return `<code>${escape(text)}</code>`;
}
/** Format the input text as a monospace block optionally with a programming language */
export function monospaceBlock(text, programmingLanguage) {
    if (programmingLanguage) {
        return `<pre><code class="language-${programmingLanguage}">${escape(text)}</code></pre>`;
    }
    return `<pre>${escape(text)}</pre>`;
}
/** Create an url with a label text */
export function url(label, url) {
    return `<a href="${url}">${label}</a>`;
}
/** Create a user mention with a label text */
export function userMention(label, userId) {
    return url(label, `tg://user?id=${userId}`);
}
